@@ -17,7 +17,7 @@ class Extractor(QtCore.QObject):
 
       self.url = ''
       self.report = 'http://gerald.fauvelle.free.fr/traintrain/report.php?version=%s&ttid=%s&error=%s&url=%s'
-      
+
       self.userAgent = 'Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900'
       self.urlPerturb = ''
       self.rideModel = RideModel(id)
@@ -27,9 +27,11 @@ class Extractor(QtCore.QObject):
       self.fetching = False
       self.id = id
       self.cpt=0
+      self.html = ''
 
       self.online = False
       self.manager = None
+      self.model = None
       self.currentRide = None
       self.parsePerturbation =  False
       self.parseDetails = False
@@ -74,6 +76,7 @@ class Extractor(QtCore.QObject):
       self.rideModel.Clear()
 
       if self.online and self.manager:
+         DebugLog("FetchDatas : "+self.url)
          request = QNetworkRequest( QtCore.QUrl(self.url) )
          request.setRawHeader("User-Agent", self.userAgent)
          request.setRawHeader( "Accept-Encoding", "gzip, deflate" )
@@ -95,7 +98,7 @@ class Extractor(QtCore.QObject):
 
       html = str(reply.readAll())
       DebugLog("readData %d"%len(html))
-         
+
       # handle compressed datas
       if reply.hasRawHeader("Content-Encoding"):
          encoding = reply.rawHeader("Content-Encoding")
@@ -135,7 +138,7 @@ class Extractor(QtCore.QObject):
       DebugLog("Extractor::Parse %s"%self.id)
 
       try:
-         self.Feed( str )
+         self.Feed(str)
       except HTMLParser.HTMLParseError, e:
          print e
 
@@ -154,14 +157,13 @@ class Extractor(QtCore.QObject):
             self.cpt=0
             for ride in self.listRides:
                if ride.detailsUrl:
-                  #DebugLog("details : %s"%self.urlPerturb)
                   request = QNetworkRequest( QtCore.QUrl(ride.detailsUrl) )
                   request.setRawHeader("User-Agent", self.userAgent)
                   self.manager.get(request)
 
       if self.extracted:
          self.fillModel(self.max)
-                  
+
       if self.error:
          self.rideModel.SetInfo('ERROR', self.error)
 
@@ -182,7 +184,7 @@ class Extractor(QtCore.QObject):
 
       if self.extracted:
          self.fillModel(self.max)
-         
+
    def AppendRidesToModel(self, imax):
       DebugLog("Extractor::AppendRidesToModel %s"%self.id)
       DebugLog("  len(self.listRides)=%d"%len(self.listRides))
@@ -190,12 +192,13 @@ class Extractor(QtCore.QObject):
       if len(self.listRides)==0:
          DebugFile(self.html, 'html_%s.html'%self.id)
          error = "error"
-         
-      v = version.appVersion
-      requestReport = QNetworkRequest( QtCore.QUrl(self.report%(v, self.model.ttConf.ttid, error, self.url)) )
-      requestReport.setRawHeader("User-Agent", self.userAgent)
-      reply = self.manager2.get(requestReport)
-      
+
+      if self.online and self.manager2:
+         v = version.appVersion
+         requestReport = QNetworkRequest( QtCore.QUrl(self.report%(v, self.model.ttConf.ttid, error, self.url)) )
+         requestReport.setRawHeader("User-Agent", self.userAgent)
+         reply = self.manager2.get(requestReport)
+
       cpt = 0
       for ride in self.listRides:
          if not ride.match:
