@@ -22,25 +22,39 @@ class TableParserMetro(Extractor, HTMLParser.HTMLParser):
       self.tagHeurePassage = False
       self.tagHeurePassageB = False
       self.tagDestination = False
+      self.tagDestinationMaybe = False
       self.tagDestinationB = False
       self.tagUnavailable = False
       self.station = False
       self.tagNoTrain = False
+      self.destination = ''
       self.train = ''
       Extractor.Clear(self)
       self.stopParsing = False
+      self.destinationDetailed = False
 
    def Feed(self, html):
       DebugLog("TableParserMetro::Feed")
       self.Clear()
       self.html = htmlTools.unescape(html.strip().decode('iso-8859-1'))
+      if self.html.find('class="schmsg1"')!=-1:
+          self.destinationDetailed = True
+          
       self.feed(self.html)
+      # if not self.destinationDetailed:
+         # for ride in self.listRides:
+            # ride.setDestination(self.arrivee)
 
    def handle_starttag(self, tag, attrs):
       if tag == 'div' and dict(attrs).has_key('class'):
-         if dict(attrs)['class'] == 'bg1' or dict(attrs)['class'] == 'bg3':
+         if dict(attrs)['class'] == 'subtitle':
+            self.tagDestinationMaybe = True
+            
+         elif dict(attrs)['class'] == 'bg1' or dict(attrs)['class'] == 'bg3':
             self.tagDestination = True
             self.currentRide = Ride()
+            self.tagHeurePassage = True
+            
          elif dict(attrs)['class'] == 'error':
             self.tagUnavailable = True
             self.currentRide = Ride()
@@ -55,13 +69,22 @@ class TableParserMetro(Extractor, HTMLParser.HTMLParser):
          self.tagDestinationB = True
 
    def handle_data(self, data):
-      if self.tagDestination:
+      if self.tagDestinationMaybe and not self.tagDestinationB:
+         if data.strip()=="Direction":
+            self.tagDestination = True
+            self.currentRide = Ride()
+         else:
+            self.tagDestinationMaybe = False
+         return
+
+      if self.tagDestination or self.tagDestinationB:
          u = data.replace('>', '').strip()
-         self.currentRide.setDestination(u)
-         
-      if self.tagDestinationB:
-         u = data.replace('>', '').strip()
-         self.currentRide.setDestination(u)
+         if not self.destinationDetailed:
+            if self.tagDestinationMaybe:
+               self.destination = u
+            self.currentRide.setDestination(self.destination)
+         else:
+            self.currentRide.setDestination(u)
 
       if self.tagHeurePassageB:
          heure = data.strip()
@@ -91,6 +114,9 @@ class TableParserMetro(Extractor, HTMLParser.HTMLParser):
          self.listRides.append(self.currentRide)
          self.currentRide = None
 
+      if self.tagDestinationMaybe and tag=='div':
+         self.tagDestinationMaybe = False
+         
       if self.tagDestination and tag=='div':
          self.tagDestination = False
          
@@ -143,6 +169,7 @@ class ExtractorMetro(TableParserMetro):
       self.station = ligne.codeDepart
       self.ligne = ligne.ligne
       self.sens = ligne.direction
+      self.arrivee = ligne.arrivee
       lineTitle = ( ('M', self.ligne, 32), self.depart+ ' > '+ligne.arrivee)
       self.rideModel.setIconTitle( lineTitle )
 
