@@ -150,7 +150,7 @@ class ExtractorTransilien(TableParserTransilien):
       urlMobi='http://transilien.mobi/TempReelSaisieSubmit.do?etapeDepart=1&etapeArrivee=1&codeGareDepart=%s&codeGareArrivee=%s'
       
       self.url = urlMobi%(self.gare_depart, self.gare_arrivee)
-      DebugLog(self.url)
+      DebugLog("init : "+self.url)
 
       TableParserTransilien.__init__(self)
 
