@@ -105,10 +105,14 @@ class TrainTrainModel(QtCore.QObject):
    def Extracted(self, rideModel):
       self.emit(QtCore.SIGNAL('extracted'), rideModel)
 
-   def RefreshDatas(self, id=''):
-      DebugLog("TrainTrainModel::RefreshDatas")
+   def RefreshDatas(self, id='', index=-1):
+      DebugLog("TrainTrainModel::RefreshDatas id=%s, idx=%d"%(id, index))
       if id:
-         self.rideList[id].FetchDatas(self, self.max)
+         DebugLog("rideModel sens=%d"%(self.rideList[id].rideModel.sens))
+         if index==-1 or self.rideList[id].rideModel.sens==index:
+            self.rideList[id].FetchDatas(self, self.max)
       else:
          for extractor in self.rideList.values():
-            extractor.FetchDatas(self, self.max)
+            DebugLog("rideModel sens %d"%extractor.rideModel.sens)
+            if index==-1 or extractor.rideModel.sens==index:
+               extractor.FetchDatas(self, self.max)
