@@ -74,9 +74,9 @@ class RideView(QtGui.QWidget):
       self.progressIcon.setFixedSize(48, 48)
       self.progressIcon.setStyleSheet("background: #fff; margin: 0; padding: 0; ")
       self.progressIcon.setContentsMargins(4, 4, 4, 4)
-
       palette = QtGui.QPalette(QtGui.QColor("#2684DB"), QtGui.QColor("#2684DB"))
       self.progressIcon.setPalette( palette )
+      self.progressIcon.hide()
       self.statusIconLayout.addWidget(self.progressIcon, Qt.AlignCenter)
 
       self.infoButton = QtGui.QPushButton()
@@ -212,10 +212,11 @@ class RideView(QtGui.QWidget):
       if size.height()==0:
          self.progress.hide()
 
-   def Refresh(self):
+   def Refresh(self, tabIndex=-1):
       DebugLog("Refresh")
-      self.Busy()
-      self.parent.model.RefreshDatas(self.model.id)
+      if tabIndex==-1 or tabIndex==self.model.sens:
+         self.Busy()
+         self.parent.model.RefreshDatas(self.model.id, tabIndex)
 
    def RefreshAuto(self):
       DebugLog("RefreshAuto")
