@@ -57,10 +57,11 @@ class TrainTrainView(QtGui.QMainWindow):
       dlg.exec_()
       self.model.ReadConfig()
       rate = self.model.ttConf.refreshRate()
+      rateS = self.model.ttConf.refreshRateSec()
       self.updateauto.setText(u"Rafraîchissement auto %s"%rate)
       for view in self.views.values():
          view.SetRefreshAutoRate(rate)
-      self.timer.setInterval(int(rate)*1000)
+      self.timer.setInterval(int(rateS)*1000)
 
    def AddRide(self):
       dlg = AddRideDlg(self.model.garesConf, self.tabW.currentIndex())
@@ -79,21 +80,52 @@ class TrainTrainView(QtGui.QMainWindow):
          rideModel = self.model.CreateAndAddRide(ride, False)
          self.AddRideView(rideModel, 2)
 
+   def IsMorning(self, stime):
+      m0 = self.model.ttConf.morningInterval()[0]
+      m1 = self.model.ttConf.morningInterval()[1]
+      return self.IsBetween(stime, m0, m1)
+   
+   def IsEvening(self, stime):
+      m0 = self.model.ttConf.eveningInterval()[0]
+      m1 = self.model.ttConf.eveningInterval()[1]
+      return self.IsBetween(stime, m0, m1)
+      
+   def IsBetween(self, stime, m0, m1):
+      if m0<m1:
+         return stime>m0 and stime<m1
+      else:
+         return not(stime>m0 and stime<m1)
+      
    def AddRideView(self, rideModel, sens):
       view = RideView(rideModel, self)
-      view.Refresh()
+      index = 0
+      stime = time.strftime("%H:%M")
+      if self.IsMorning(stime):
+         index = 0
+      elif self.IsEvening(stime):
+         index = 1
+      else:
+         index = -1
+         
+      view.Refresh(index)
       self.views[rideModel.id] = view
       if sens==0:
          self.layoutAller.addWidget( view )
-
       elif sens==1:
          self.layoutRetour.addWidget( view )
-
       elif sens==2:
          self.layoutSimple.addWidget( view )
 
    def PrepareView(self):
       DebugLog("TrainTrainView::PrepareView")
+      stime = time.strftime("%H:%M")
+      if self.IsMorning(stime):
+         self.tabW.setCurrentIndex(0)
+      elif self.IsEvening(stime):
+         self.tabW.setCurrentIndex(1)
+      else:
+         self.tabW.setCurrentIndex(0)
+         
       for rideModel in self.model.GetRidesModel():
          self.AddRideView(rideModel, rideModel.sens)
 
@@ -234,10 +266,7 @@ class TrainTrainView(QtGui.QMainWindow):
       DebugLog("TrainTrainView::Refresh")
       self.updateCpt=0
       self.SetLoading(True)
-
-      for view in self.views.values():
-         view.Busy()
-      self.model.RefreshDatas()
+      self.model.RefreshDatas(None, self.tabW.currentIndex())
 
    def RefreshAuto(self):
       if self.timer.isActive():
